@@ -24,7 +24,7 @@ class Timer:
     @contextmanager
     def time(self) -> Generator[None, None, None]:
         """
-        Context manager to time a code block and add the result to the internal ticks list
+        Context manager to time in seconds a code block and add the result to the internal ticks list
         """
 
         start_time = time.perf_counter()
@@ -53,3 +53,21 @@ class Timer:
         """
 
         return sum(self.ticks) / len(self.ticks)
+
+    def get_max_tick_time(self) -> float:
+        """
+        Get the maximum tick time from the list of ticks within this timer
+
+        :return: Maximum tick time
+        """
+
+        return max(self.ticks)
+
+    def get_min_tick_time(self) -> float:
+        """
+        Get the minimum tick time from the list of ticks within this timer
+
+        :return: Minimum tick time
+        """
+
+        return min(self.ticks)
