@@ -1,8 +1,8 @@
 import pytest
 
-from pylemetry import Registry
+from pylemetry import registry
 
 
 @pytest.fixture(autouse=True)
 def clear_registry() -> None:
-    Registry().clear()
+    registry.clear()
