@@ -1,11 +1,11 @@
 import pytest
 
-from pylemetry import Registry
+from pylemetry import registry
 from pylemetry.decorators import count
 from pylemetry.meters import Counter
 
 
-@count
+@count()
 def mock_function() -> str:
     return "A function decorated with the count decorator"
 
@@ -13,11 +13,11 @@ def mock_function() -> str:
 def test_count_decorator_creates_counter_in_registry() -> None:
     counter_name = "mock_function"
 
-    assert Registry().get_counter(counter_name) is None
+    assert registry.get_counter(counter_name) is None
 
     mock_function()
 
-    counter = Registry().get_counter(counter_name)
+    counter = registry.get_counter(counter_name)
 
     assert isinstance(counter, Counter)
     assert counter.get_count() == 1
@@ -27,12 +27,22 @@ def test_count_decorator_creates_counter_in_registry() -> None:
 def test_count_decorator_updates_existing_counter(call_count: int) -> None:
     counter_name = "mock_function"
 
-    assert Registry().get_counter(counter_name) is None
+    assert registry.get_counter(counter_name) is None
 
     for _ in range(call_count):
         mock_function()
 
-    counter = Registry().get_counter(counter_name)
+    counter = registry.get_counter(counter_name)
 
     assert isinstance(counter, Counter)
     assert counter.get_count() == call_count
+
+
+def test_count_decorator_with_name() -> None:
+    @count(name="test_count_meter")
+    def mock() -> None:
+        print("Mock method")
+
+    mock()
+
+    assert "test_count_meter" in registry.COUNTERS
